==> cdk_2.7.1.orig.tar.gz: cdk-cdk-2.7.1/storage/io/src/main/java/org/openscience/cdk/dict/DictRef.java <==
/* Copyright (C) 2003-2008  Egon Willighagen <egonw@users.sf.net>
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 * All we ask is that proper credit is given for our work, which includes
 * - but is not limited to - adding the above copyright notice to the beginning
 * of your source code files, and to any copyright notice that you may distribute
 * with programs based on this work.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */
package org.openscience.cdk.dict;


/**
 * Object that can be used as key in IChemObject.setProperty(key, value) to
 * denote that this property is a dictionary reference for this IChemObject.
 *
 * @author      Egon Willighagen
 * @cdk.created 2003-08-24
 * @cdk.module  standard
 * @cdk.githash
 */
public class DictRef implements java.io.Serializable, Cloneable {

    private static final long serialVersionUID = -3691244168587563625L;

    String                    type;
    String                    reference;

    public DictRef(String type, String dictRef) {
        this.type = type;
        this.reference = dictRef;
    }

    public String getReference() {
        return reference;
    }

    public String getType() {
        return type;
    }

    @Override
    public String toString() {
        return "DictRef{T=" + this.type + ", R=" + reference + "}";
    }

}

==> cdk_2.11.orig.tar.gz: cdk-cdk-2.11/storage/io/src/main/java/org/openscience/cdk/dict/DictRef.java <==
/* Copyright (C) 2003-2008  Egon Willighagen <egonw@users.sf.net>
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 * All we ask is that proper credit is given for our work, which includes
 * - but is not limited to - adding the above copyright notice to the beginning
 * of your source code files, and to any copyright notice that you may distribute
 * with programs based on this work.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */
package org.openscience.cdk.dict;


/**
 * Object that can be used as key in IChemObject.setProperty(key, value) to
 * denote that this property is a dictionary reference for this IChemObject.
 *
 * @author      Egon Willighagen
 * @cdk.created 2003-08-24
 */
public class DictRef implements java.io.Serializable, Cloneable {

    private static final long serialVersionUID = -3691244168587563625L;

    final String                    type;
    final String                    reference;

    public DictRef(String type, String dictRef) {
        this.type = type;
        this.reference = dictRef;
    }

    public String getReference() {
        return reference;
    }

    public String getType() {
        return type;
    }

    @Override
    public String toString() {
        return "DictRef{T=" + this.type + ", R=" + reference + "}";
    }

}
